@@ -12,6 +12,7 @@ from .account import *
 from .asset import *
 from .client.aiohttp_client import AiohttpClient
 from .client.requests_client import RequestsClient
+from .decorated_signature import *
 from .fee_bump_transaction import *
 from .fee_bump_transaction_envelope import *
 from .helpers import *
@@ -24,8 +25,10 @@ from .network import *
 from .operation import *
 from .price import *
 from .server import *
+from .server_async import *
 from .signer import *
 from .signer_key import *
+from .strkey import *
 from .time_bounds import *
 from .transaction import *
 from .transaction_builder import *
