@@ -2,22 +2,25 @@ from abc import abstractmethod
 from typing import Generic, List, TypeVar, Union
 
 from . import xdr as stellar_xdr
+from .decorated_signature import DecoratedSignature
 from .exceptions import SignatureExistError
 from .keypair import Keypair
 from .network import Network
+from .type_checked import type_checked
 from .utils import hex_to_bytes, sha256
 
 T = TypeVar("T")
 
 
+@type_checked
 class BaseTransactionEnvelope(Generic[T]):
     def __init__(
         self,
         network_passphrase: str,
-        signatures: List[stellar_xdr.DecoratedSignature] = None,
+        signatures: List[DecoratedSignature] = None,
     ) -> None:
         self.network_passphrase: str = network_passphrase
-        self.signatures: List[stellar_xdr.DecoratedSignature] = signatures or []
+        self.signatures: List[DecoratedSignature] = signatures or []
         self._network_id: bytes = Network(network_passphrase).network_id()
 
     def hash(self) -> bytes:
@@ -54,8 +57,7 @@ class BaseTransactionEnvelope(Generic[T]):
             signer = Keypair.from_secret(signer)
         tx_hash = self.hash()
         sig = signer.sign_decorated(tx_hash)
-        sig_dict = [signature.__dict__ for signature in self.signatures]
-        if sig.__dict__ in sig_dict:
+        if sig in self.signatures:
             raise SignatureExistError("The keypair has already signed.")
         else:
             self.signatures.append(sig)
@@ -80,19 +82,16 @@ class BaseTransactionEnvelope(Generic[T]):
         """Sign this transaction envelope with a Hash(x) signature.
 
         See Stellar's documentation on `Multi-Sig
-        <https://www.stellar.org/developers/guides/concepts/multi-sig.html>`_
+        <https://developers.stellar.org/docs/glossary/multisig/>`_
         for more details on Hash(x) signatures.
 
         :param preimage: Preimage of hash used as signer, byte hash or hex encoded string
         """
         preimage_bytes: bytes = hex_to_bytes(preimage)
         hash_preimage = sha256(preimage_bytes)
-        hint = stellar_xdr.SignatureHint(hash_preimage[-4:])
-        sig = stellar_xdr.DecoratedSignature(
-            hint, stellar_xdr.Signature(preimage_bytes)
-        )
-        sig_dict = [signature.__dict__ for signature in self.signatures]
-        if sig.__dict__ in sig_dict:
+        hint = hash_preimage[-4:]
+        sig = DecoratedSignature(hint, preimage_bytes)
+        if sig in self.signatures:
             raise SignatureExistError("The preimage has already signed.")
         else:
             self.signatures.append(sig)
