@@ -12,19 +12,21 @@ from ..__version__ import __version__
 from ..client.base_sync_client import BaseSyncClient
 from ..client.response import Response
 from ..exceptions import ConnectionError
+from ..type_checked import type_checked
 from . import defines
 
 DEFAULT_NUM_RETRIES = 3
 DEFAULT_BACKOFF_FACTOR = 0.5
-USER_AGENT = f"py-stellar-sdk/{__version__}/RequestsClient"
+USER_AGENT = f"py-stellar-base/{__version__}/RequestsClient"
 IDENTIFICATION_HEADERS = {
-    "X-Client-Name": "py-stellar-sdk",
+    "X-Client-Name": "py-stellar-base",
     "X-Client-Version": __version__,
 }
 
 __all__ = ["RequestsClient"]
 
 
+@type_checked
 class RequestsClient(BaseSyncClient):
     """The :class:`RequestsClient` object is a synchronous http client,
     which represents the interface for making requests to a server instance.
@@ -38,7 +40,7 @@ class RequestsClient(BaseSyncClient):
     :param stream_session: the stream request session
     """
 
-    # TODO: Custom user agent.
+    # TODO: need to allow the user to customize the user agent?
     def __init__(
         self,
         pool_size: int = DEFAULT_POOLSIZE,
@@ -152,7 +154,7 @@ class RequestsClient(BaseSyncClient):
     ) -> Generator[Dict[str, Any], None, None]:
         """Creates an EventSource that listens for incoming messages from the server.
 
-        See `Horizon Response Format <https://www.stellar.org/developers/horizon/reference/responses.html>`_
+        See `Horizon Response Format <https://developers.stellar.org/api/introduction/response-format/>`__
 
         See `MDN EventSource <https://developer.mozilla.org/en-US/docs/Web/API/EventSource>`_
 
