@@ -1,8 +1,11 @@
 import json
 
+from ..type_checked import type_checked
+
 __all__ = ["Response"]
 
 
+@type_checked
 class Response:
     """The :class:`Response <Response>` object, which contains a
     server's response to an HTTP request.
@@ -28,7 +31,7 @@ class Response:
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return (
             self.status_code == other.status_code
             and self.text == other.text
@@ -37,4 +40,9 @@ class Response:
         )
 
     def __str__(self):
-        return f"<Response [{self.status_code}]>"
+        return (
+            f"<Response [status_code={self.status_code}, "
+            f"text={self.text}, "
+            f"headers={self.headers}, "
+            f"url={self.url}]>"
+        )
