@@ -6,17 +6,20 @@ from .keypair import Keypair
 from .muxed_account import MuxedAccount
 from .transaction import Transaction
 from .transaction_envelope import TransactionEnvelope
+from .type_checked import type_checked
 
 BASE_FEE = 100
 
 __all__ = ["FeeBumpTransaction"]
 
 
+@type_checked
 class FeeBumpTransaction:
     """The :class:`FeeBumpTransaction` object, which represents a fee bump transaction
     on Stellar's network.
 
-    See `CAP-0015 <https://github.com/stellar/stellar-protocol/blob/master/core/cap-0015.md>`_ for more information.
+    See `Fee-Bump Transactions <https://developers.stellar.org/docs/glossary/fee-bumps/>`__ for more information.
+    See `CAP-0015 <https://github.com/stellar/stellar-protocol/blob/master/core/cap-0015.md>`__ for more information.
 
     :param fee_source: The account paying for the transaction.
     :param base_fee: The max fee willing to pay per operation in inner transaction (**in stroops**).
@@ -29,25 +32,24 @@ class FeeBumpTransaction:
         base_fee: int,
         inner_transaction_envelope: TransactionEnvelope,
     ) -> None:
-        if not isinstance(inner_transaction_envelope.transaction, Transaction):
-            raise ValueError(
-                "Invalid `inner_transaction`, it should be `stellar_sdk.transaction.Transaction`."
-            )
-
         if isinstance(fee_source, str):
             fee_source = MuxedAccount.from_account(fee_source)
         if isinstance(fee_source, Keypair):
             fee_source = MuxedAccount.from_account(fee_source.public_key)
 
         self.fee_source: MuxedAccount = fee_source
-        self.base_fee = base_fee
-        self.inner_transaction_envelope = (
+        self.base_fee: int = base_fee
+        self.inner_transaction_envelope: TransactionEnvelope = (
             inner_transaction_envelope.to_transaction_envelope_v1()
         )
-        self._inner_transaction = self.inner_transaction_envelope.transaction
+        self._inner_transaction: Transaction = (
+            self.inner_transaction_envelope.transaction
+        )
 
-        inner_operations_length = len(self._inner_transaction.operations)
-        inner_base_fee_rate = self._inner_transaction.fee / inner_operations_length
+        inner_operations_length: int = len(self._inner_transaction.operations)
+        inner_base_fee_rate: int = int(
+            self._inner_transaction.fee / inner_operations_length
+        )
         if self.base_fee < inner_base_fee_rate or self.base_fee < BASE_FEE:
             raise ValueError(
                 f"Invalid `base_fee`, it should be at least {self._inner_transaction.fee if self._inner_transaction.fee > BASE_FEE else BASE_FEE} stroops."
@@ -116,7 +118,7 @@ class FeeBumpTransaction:
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return self.to_xdr_object() == other.to_xdr_object()
 
     def __str__(self):
