@@ -1,22 +1,20 @@
 import os
-from typing import Any, Union
+from typing import Union
 
 import nacl.signing as ed25519
 from nacl.exceptions import BadSignatureError as NaclBadSignatureError
 
 from . import xdr as stellar_xdr
-from .exceptions import (
-    AttributeError,
-    BadSignatureError,
-    MissingEd25519SecretSeedError,
-    TypeError,
-)
+from .decorated_signature import DecoratedSignature
+from .exceptions import AttributeError, BadSignatureError, MissingEd25519SecretSeedError
 from .sep.mnemonic import Language, StellarMnemonic
 from .strkey import StrKey
+from .type_checked import type_checked
 
 __all__ = ["Keypair"]
 
 
+@type_checked
 class Keypair:
     """The :class:`Keypair` object, which represents a signing and
     verifying key for use with the Stellar network.
@@ -28,6 +26,9 @@ class Keypair:
     * :meth:`Keypair.from_secret`
     * :meth:`Keypair.from_public_key`
 
+    Learn how to create a key through our documentation:
+    `Generate Keypair <https://stellar-sdk.readthedocs.io/en/latest/generate_keypair.html>`__.
+
     :param verify_key: The verifying (public) Ed25519 key in the keypair.
     :param signing_key: The signing (private) Ed25519 key in the keypair.
     """
@@ -35,30 +36,26 @@ class Keypair:
     def __init__(
         self, verify_key: ed25519.VerifyKey, signing_key: ed25519.SigningKey = None
     ) -> None:
-        self.verify_key: ed25519.VerifyKey = _get_key_of_expected_type(
-            verify_key, ed25519.VerifyKey
-        )
-        self.signing_key: ed25519.SigningKey = _get_key_of_expected_type(
-            signing_key, ed25519.SigningKey
-        )
+        self.verify_key: ed25519.VerifyKey = verify_key
+        self.signing_key: ed25519.SigningKey = signing_key
 
     @classmethod
     def random(cls) -> "Keypair":
         """Generate a :class:`Keypair` object from a randomly generated seed.
 
-        :return: A new :class:`Keypair` instance derived by the randomly seed.
+        :return: A new :class:`Keypair` object derived by the randomly seed.
         """
         seed = os.urandom(32)
         return cls.from_raw_ed25519_seed(seed)
 
     @classmethod
     def from_secret(cls, secret: str) -> "Keypair":
-        """Generate a :class:`Keypair` object from a secret seed.
+        """Generate a :class:`Keypair` object from a secret key.
 
-        :param secret: strkey ed25519 seed, for example: `SB2LHKBL24ITV2Y346BU46XPEL45BDAFOOJLZ6SESCJZ6V5JMP7D6G5X`
-        :return: A new :class:`Keypair` instance derived by the secret.
+        :param secret: secret key (ex. ``"SB2LHKBL24ITV2Y346BU46XPEL45BDAFOOJLZ6SESCJZ6V5JMP7D6G5X"``)
+        :return: A new :class:`Keypair` object derived by the secret.
         :raise: :exc:`Ed25519SecretSeedInvalidError <stellar_sdk.exceptions.Ed25519SecretSeedInvalidError>`:
-            if ``secret`` is not a valid ed25519 secret seed.
+            if `secret` is not a valid ed25519 secret seed.
         """
         raw_secret = StrKey.decode_ed25519_secret_seed(secret)
         return cls.from_raw_ed25519_seed(raw_secret)
@@ -67,11 +64,10 @@ class Keypair:
     def from_public_key(cls, public_key: str) -> "Keypair":
         """Generate a :class:`Keypair` object from a public key.
 
-        :param public_key: strkey ed25519 public key,
-            for example: `GATPGGOIE6VWADVKD3ER3IFO2IH6DTOA5G535ITB3TT66FZFSIZEAU2B`
-        :return: A new :class:`Keypair` instance derived by the public key.
+        :param public_key: public key (ex. ``"GATPGGOIE6VWADVKD3ER3IFO2IH6DTOA5G535ITB3TT66FZFSIZEAU2B"``)
+        :return: A new :class:`Keypair` object derived by the public key.
         :raise: :exc:`Ed25519PublicKeyInvalidError <stellar_sdk.exceptions.Ed25519PublicKeyInvalidError>`:
-            if ``public_key`` is not a valid ed25519 public key.
+            if `public_key` is not a valid ed25519 public key.
         """
         key = StrKey.decode_ed25519_public_key(public_key)
         return cls.from_raw_ed25519_public_key(key)
@@ -81,7 +77,7 @@ class Keypair:
         """Generate a :class:`Keypair` object from ed25519 secret key seed raw bytes.
 
         :param raw_seed: ed25519 secret key seed raw bytes
-        :return: A new :class:`Keypair` instance derived by the ed25519 secret key seed raw bytes
+        :return: A new :class:`Keypair` object derived by the ed25519 secret key seed raw bytes
         """
         signing_key = ed25519.SigningKey(raw_seed)
         verify_key = signing_key.verify_key
@@ -92,14 +88,14 @@ class Keypair:
         """Generate a :class:`Keypair` object from ed25519 public key raw bytes.
 
         :param raw_public_key: ed25519 public key raw bytes
-        :return: A new :class:`Keypair` instance derived by the ed25519 public key raw bytes
+        :return: A new :class:`Keypair` object derived by the ed25519 public key raw bytes
         """
         verify_key = ed25519.VerifyKey(raw_public_key)
         return cls(verify_key)
 
     @property
     def secret(self) -> str:
-        """Returns secret key associated with this :class:`Keypair` instance
+        """Returns secret key associated with this :class:`Keypair` object
 
         :return: secret key
         :raise: :exc:`MissingEd25519SecretSeedError <stellar_sdk.exceptions.MissingEd25519SecretSeedError>`
@@ -107,10 +103,10 @@ class Keypair:
         """
         if not self.signing_key:
             raise MissingEd25519SecretSeedError(
-                "The keypair does not contain secret seed. Use Keypair.from_secret or "
-                "Keypair.random to create a new keypair with a secret seed."
+                "The keypair does not contain secret seed. Use Keypair.from_secret, "
+                "Keypair.random or Keypair.from_mnemonic_phrase to create a new keypair with a secret seed."
             )
-
+        # return None is a better approach
         return StrKey.encode_ed25519_secret_seed(self.raw_secret_key())
 
     @secret.setter
@@ -121,7 +117,7 @@ class Keypair:
 
     @property
     def public_key(self) -> str:
-        """Returns public key associated with this :class:`Keypair` instance
+        """Returns public key associated with this :class:`Keypair` object
 
         :return: public key
         """
@@ -159,7 +155,7 @@ class Keypair:
         return bytes(self.verify_key)
 
     def signature_hint(self) -> bytes:
-        """Returns signature hint associated with this :class:`Keypair` instance
+        """Returns signature hint associated with this :class:`Keypair` object
 
         :return: signature hint
         """
@@ -192,8 +188,8 @@ class Keypair:
         """
         if not self.can_sign():
             raise MissingEd25519SecretSeedError(
-                "The keypair does not contain secret seed. Use Keypair.from_secret or "
-                "Keypair.random to create a new keypair with a secret seed."
+                "The keypair does not contain secret seed. Use Keypair.from_secret, "
+                "Keypair.random or Keypair.from_mnemonic_phrase to create a new keypair with a secret seed."
             )
         return self.signing_key.sign(data).signature
 
@@ -213,11 +209,12 @@ class Keypair:
     @staticmethod
     def generate_mnemonic_phrase(
         language: Union[Language, str] = Language.ENGLISH, strength: int = 128
-    ):
+    ) -> str:
         """Generate a mnemonic phrase.
 
         :param language: The language of the mnemonic phrase, defaults to english.
-        :param strength: The complexity of the mnemonic.
+        :param strength: The complexity of the mnemonic, its possible value
+            is ``128``, ``160``, ``192``, ``224`` and ``256``.
         :return: A mnemonic phrase.
         """
         mnemonic_phrase = StellarMnemonic(language).generate(strength)
@@ -230,7 +227,7 @@ class Keypair:
         language: Union[Language, str] = Language.ENGLISH,
         passphrase: str = "",
         index: int = 0,
-    ):
+    ) -> "Keypair":
         """Generate a :class:`Keypair` object via a mnemonic
         phrase.
 
@@ -247,38 +244,30 @@ class Keypair:
             >>> kp1 = Keypair.from_mnemonic_phrase(mnemonic, index=0)
             >>> kp2 = Keypair.from_mnemonic_phrase(mnemonic, index=1)
             >>> kp3 = Keypair.from_mnemonic_phrase(mnemonic, index=2)
-        :return: A new :class:`Keypair` instance derived from the mnemonic.
+        :return: A new :class:`Keypair` object derived from the mnemonic.
         """
         raw_ed25519_seed = StellarMnemonic(language).to_seed(
             mnemonic_phrase, passphrase, index
         )
         return cls.from_raw_ed25519_seed(raw_ed25519_seed)
 
-    def sign_decorated(self, data) -> stellar_xdr.DecoratedSignature:
+    def sign_decorated(self, data: bytes) -> DecoratedSignature:
         """Sign the provided data with the keypair's private key and returns DecoratedSignature.
 
         :param data: signed bytes
         :return: sign decorated
         """
-        hint = stellar_xdr.SignatureHint(self.signature_hint())
-        signature = stellar_xdr.Signature(self.sign(data))
-        return stellar_xdr.DecoratedSignature(hint, signature)
+        hint = self.signature_hint()
+        signature = self.sign(data)
+        return DecoratedSignature(hint, signature)
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return (
             self.verify_key == other.verify_key
             and self.signing_key == other.signing_key
         )
 
     def __str__(self):
-        return f"<Keypair [public_key={self.public_key}, private_key_exists={self.signing_key is not None}]>"
-
-
-def _get_key_of_expected_type(key: Any, expected_type: Any) -> Any:
-    if key is not None and not isinstance(key, expected_type):
-        raise TypeError(
-            f"The given key_type={type(key)} is not of type {expected_type}."
-        )
-    return key
+        return f"<Keypair [public_key={self.public_key}, private_key_exists={self.can_sign()}]>"
