@@ -7,8 +7,9 @@ from ..asset import Asset
 from ..keypair import Keypair
 from ..muxed_account import MuxedAccount
 from ..strkey import StrKey
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_ed25519_public_key
 from .operation import Operation
-from .utils import check_asset_code, check_ed25519_public_key
 
 __all__ = ["TrustLineEntryFlag", "AllowTrust"]
 
@@ -17,11 +18,11 @@ class TrustLineEntryFlag(IntFlag):
     """Indicates which flags to set. For details about the flags,
     please refer to the `CAP-0018 <https://github.com/stellar/stellar-protocol/blob/master/core/cap-0018.md>`_.
 
-    - UNAUTHORIZED_FLAG: The account can hold a balance but cannot receive payments, send payments, maintain offers or manage offers
+    - **UNAUTHORIZED_FLAG**: The account can hold a balance but cannot receive payments, send payments, maintain offers or manage offers
 
-    - AUTHORIZED_FLAG: The account can hold a balance, receive payments, send payments, maintain offers or manage offers
+    - **AUTHORIZED_FLAG**: The account can hold a balance, receive payments, send payments, maintain offers or manage offers
 
-    - AUTHORIZED_TO_MAINTAIN_LIABILITIES_FLAG: The account can hold a balance and maintain offers but cannot receive payments, send payments or manage offers
+    - **AUTHORIZED_TO_MAINTAIN_LIABILITIES_FLAG**: The account can hold a balance and maintain offers but cannot receive payments, send payments or manage offers
     """
 
     UNAUTHORIZED_FLAG = 0
@@ -29,25 +30,28 @@ class TrustLineEntryFlag(IntFlag):
     AUTHORIZED_TO_MAINTAIN_LIABILITIES_FLAG = 2
 
 
+@type_checked
 class AllowTrust(Operation):
     """The :class:`AllowTrust` object, which represents a AllowTrust operation
     on Stellar's network.
 
     Updates the authorized flag of an existing trustline. This can only be
     called by the issuer of a trustline's `asset
-    <https://www.stellar.org/developers/guides/concepts/assets.html>`_.
+    <https://developers.stellar.org/docs/glossary/assets/>`_.
 
     The issuer can only clear the authorized flag if the issuer has the
-    AUTH_REVOCABLE_FLAG set. Otherwise, the issuer can only set the authorized
+    ``AUTH_REVOCABLE_FLAG`` set. Otherwise, the issuer can only set the authorized
     flag.
 
     Threshold: Low
 
+    See `Allow Trust <https://developers.stellar.org/docs/start/list-of-operations/#allow-trust>`_ for more information.
+
     :param trustor: The trusting account (the one being authorized).
     :param asset_code: The asset code being authorized.
     :param authorize: `True` to authorize the line, `False` to deauthorize，if you need further control,
         you can also use :class:`stellar_sdk.operation.allow_trust.TrustLineEntryFlag`.
-    :param source: The source account (defaults to transaction source).
+    :param source: The source account for the operation. Defaults to the transaction's source account.
 
     """
 
@@ -68,8 +72,7 @@ class AllowTrust(Operation):
             DeprecationWarning,
         )
         super().__init__(source)
-        check_ed25519_public_key(trustor)
-        check_asset_code(asset_code)
+
         self.trustor: str = trustor
         self.asset_code: str = asset_code
 
@@ -80,9 +83,10 @@ class AllowTrust(Operation):
                 self.authorize = TrustLineEntryFlag.UNAUTHORIZED_FLAG
         else:
             self.authorize = authorize
+        raise_if_not_valid_ed25519_public_key(self.trustor, "trustor")
+        Asset.check_if_asset_code_is_valid(self.asset_code)
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
-        Asset.check_if_asset_code_is_valid(self.asset_code)
         trustor = Keypair.from_public_key(self.trustor).xdr_account_id()
         length = len(self.asset_code)
         pad_length = 4 - length if length <= 4 else 12 - length
