@@ -4,26 +4,27 @@ from .. import xdr as stellar_xdr
 from ..keypair import Keypair
 from ..muxed_account import MuxedAccount
 from ..strkey import StrKey
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_ed25519_public_key
 from .operation import Operation
-from .utils import check_ed25519_public_key
 
 __all__ = ["BeginSponsoringFutureReserves"]
 
 
+@type_checked
 class BeginSponsoringFutureReserves(Operation):
     """The :class:`BeginSponsoringFutureReserves` object, which represents a BeginSponsoringFutureReserves
     operation on Stellar's network.
 
     Establishes the is-sponsoring-future-reserves-for relationship between the source account and sponsoredID.
-    See `Sponsored Reserves <https://developers.stellar.org/docs/glossary/sponsored-reserves/>_` for more information.
-
-    See `Begin Sponsoring Future Reserves
-    <https://developers.stellar.org/docs/start/list-of-operations/#begin-sponsoring-future-reserves>_`.
+    See `Sponsored Reserves <https://developers.stellar.org/docs/glossary/sponsored-reserves/>`_ for more information.
 
     Threshold: Medium
 
+    See `Begin Sponsoring Future Reserves <https://developers.stellar.org/docs/start/list-of-operations/#begin-sponsoring-future-reserves>`_ for more information.
+
     :param sponsored_id: The sponsored account id.
-    :param source: The source account (defaults to transaction source).
+    :param source: The source account for the operation. Defaults to the transaction's source account.
     """
 
     _XDR_OPERATION_TYPE: stellar_xdr.OperationType = (
@@ -34,8 +35,8 @@ class BeginSponsoringFutureReserves(Operation):
         self, sponsored_id: str, source: Optional[Union[MuxedAccount, str]] = None
     ) -> None:
         super().__init__(source)
-        check_ed25519_public_key(sponsored_id)
         self.sponsored_id: str = sponsored_id
+        raise_if_not_valid_ed25519_public_key(self.sponsored_id, "sponsored_id")
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
         sponsored_id = Keypair.from_public_key(self.sponsored_id).xdr_account_id()
