@@ -2,11 +2,13 @@ from typing import Optional, Union
 
 from .. import xdr as stellar_xdr
 from ..muxed_account import MuxedAccount
+from ..type_checked import type_checked
 from .operation import Operation
 
 __all__ = ["BumpSequence"]
 
 
+@type_checked
 class BumpSequence(Operation):
     """The :class:`BumpSequence` object, which represents a
     BumpSequence operation on Stellar's network.
@@ -18,6 +20,8 @@ class BumpSequence(Operation):
 
     Threshold: Low
 
+    See `Bump Sequence <https://developers.stellar.org/docs/start/list-of-operations/#bump-sequence>`_ for more information.
+
     :param bump_to: Sequence number to bump to.
     :param source: The optional source account.
 
