@@ -5,26 +5,30 @@ from .. import xdr as stellar_xdr
 from ..asset import Asset
 from ..liquidity_pool_asset import LiquidityPoolAsset
 from ..muxed_account import MuxedAccount
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_amount
 from .operation import Operation
-from .utils import check_amount
 
 __all__ = ["ChangeTrust"]
 
 
+@type_checked
 class ChangeTrust(Operation):
     """The :class:`ChangeTrust` object, which represents a ChangeTrust
     operation on Stellar's network.
 
     Creates, updates, or deletes a trustline. For more on trustlines, please
     refer to the `assets documentation
-    <https://www.stellar.org/developers/guides/concepts/assets.html>_`.
+    <https://developers.stellar.org/docs/glossary/assets/>`_.
 
     Threshold: Medium
 
+    See `Change Trust <https://developers.stellar.org/docs/start/list-of-operations/#change-trust>`_ for more information.
+
     :param asset: The asset for the trust line.
-    :param limit: The limit for the asset, defaults to max int64(922337203685.4775807).
-        If the limit is set to "0" it deletes the trustline.
-    :param source: The source account (defaults to transaction source).
+    :param limit: The limit for the asset, defaults to max int64(``922337203685.4775807``).
+        If the limit is set to ``"0"`` it deletes the trustline.
+    :param source: The source account for the operation. Defaults to the transaction's source account.
 
     """
 
@@ -37,18 +41,17 @@ class ChangeTrust(Operation):
     def __init__(
         self,
         asset: Union[Asset, LiquidityPoolAsset],
-        limit: Union[str, Decimal] = None,
+        limit: Union[str, Decimal, None] = None,  # TODO: _DEFAULT_LIMIT default
         source: Optional[Union[MuxedAccount, str]] = None,
     ) -> None:
         super().__init__(source)
         self.asset = asset
-        if (
-            limit is None
-        ):  # We don't need this if the user can send the value with correct type.
-            self.limit: Union[str, Decimal] = self._DEFAULT_LIMIT
+        if limit is None:
+            self.limit: str = self._DEFAULT_LIMIT
         else:
-            check_amount(limit)
+            limit = str(limit)
             self.limit = limit
+        raise_if_not_valid_amount(self.limit, "limit")
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
         line = self.asset.to_change_trust_asset_xdr_object()
