@@ -4,24 +4,26 @@ from typing import Optional, Union
 
 from .. import xdr as stellar_xdr
 from ..muxed_account import MuxedAccount
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_balance_id
 from .operation import Operation
 
 __all__ = ["ClaimClaimableBalance"]
 
 
+@type_checked
 class ClaimClaimableBalance(Operation):
     """The :class:`ClaimClaimableBalance` object, which represents a ClaimClaimableBalance
     operation on Stellar's network.
 
     Claims a ClaimableBalanceEntry and adds the amount of asset on the entry to the source account.
 
-    See `Claim Claimable Balance Documentation
-    <https://developers.stellar.org/docs/start/list-of-operations/#claim-claimable-balance>_`.
-
     Threshold: Low
 
+    See `Claim Claimable Balance <https://developers.stellar.org/docs/start/list-of-operations/#claim-claimable-balance>`_ for more information.
+
     :param balance_id: The claimable balance id to be claimed.
-    :param source: The source account (defaults to transaction source).
+    :param source: The source account for the operation. Defaults to the transaction's source account.
     """
 
     _XDR_OPERATION_TYPE: stellar_xdr.OperationType = (
@@ -35,6 +37,7 @@ class ClaimClaimableBalance(Operation):
     ) -> None:
         super().__init__(source)
         self.balance_id: str = balance_id
+        raise_if_not_valid_balance_id(self.balance_id, "balance_id")
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
         balance_id_bytes: bytes = binascii.unhexlify(self.balance_id)
