@@ -8,8 +8,9 @@ from ..exceptions import ValueError
 from ..keypair import Keypair
 from ..muxed_account import MuxedAccount
 from ..strkey import StrKey
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_amount, raise_if_not_valid_ed25519_public_key
 from .operation import Operation
-from .utils import check_amount
 
 __all__ = ["ClaimPredicate", "Claimant", "CreateClaimableBalance"]
 
@@ -25,6 +26,7 @@ class ClaimPredicateType(IntEnum):
     CLAIM_PREDICATE_BEFORE_RELATIVE_TIME = 5
 
 
+@type_checked
 class ClaimPredicateGroup:
     """Used to assemble the left and right values for and_predicates and or_predicates.
 
@@ -38,13 +40,14 @@ class ClaimPredicateGroup:
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return self.left == other.left and self.right == other.right
 
     def __str__(self):
         return f"<ClaimPredicateGroup [left={self.left}, right={self.right}]>"
 
 
+@type_checked
 class ClaimPredicate:
     """The :class:`ClaimPredicate` object, which represents a ClaimPredicate on Stellar's network.
 
@@ -78,11 +81,11 @@ class ClaimPredicate:
     def predicate_and(
         cls, left: "ClaimPredicate", right: "ClaimPredicate"
     ) -> "ClaimPredicate":
-        """Returns an `and` claim predicate
+        """Returns an **and** claim predicate
 
         :param left: a ClaimPredicate.
         :param right: a ClaimPredicate.
-        :return: an `and` claim predicate.
+        :return: an **and** claim predicate.
         """
         return cls(
             claim_predicate_type=ClaimPredicateType.CLAIM_PREDICATE_AND,
@@ -97,11 +100,11 @@ class ClaimPredicate:
     def predicate_or(
         cls, left: "ClaimPredicate", right: "ClaimPredicate"
     ) -> "ClaimPredicate":
-        """Returns an `or` claim predicate
+        """Returns an **or** claim predicate
 
         :param left: a ClaimPredicate.
         :param right: a ClaimPredicate.
-        :return: an `or` claim predicate.
+        :return: an **or** claim predicate.
         """
         return cls(
             claim_predicate_type=ClaimPredicateType.CLAIM_PREDICATE_OR,
@@ -114,10 +117,10 @@ class ClaimPredicate:
 
     @classmethod
     def predicate_not(cls, predicate: "ClaimPredicate") -> "ClaimPredicate":
-        """Returns a `not` claim predicate.
+        """Returns a **not** claim predicate.
 
         :param predicate: a ClaimPredicate.
-        :return: a `not` claim predicate.
+        :return: a **not** claim predicate.
         """
         return cls(
             claim_predicate_type=ClaimPredicateType.CLAIM_PREDICATE_NOT,
@@ -130,13 +133,13 @@ class ClaimPredicate:
 
     @classmethod
     def predicate_before_absolute_time(cls, abs_before: int) -> "ClaimPredicate":
-        """Returns a `before_absolute_time` claim predicate.
+        """Returns a **before_absolute_time** claim predicate.
 
         This predicate will be fulfilled if the closing time of the ledger that includes
         the :class:`CreateClaimableBalance` operation is less than this (absolute) Unix timestamp.
 
         :param abs_before: Unix epoch.
-        :return: a `before_absolute_time` claim predicate.
+        :return: a **before_absolute_time** claim predicate.
         """
         return cls(
             claim_predicate_type=ClaimPredicateType.CLAIM_PREDICATE_BEFORE_ABSOLUTE_TIME,
@@ -149,14 +152,14 @@ class ClaimPredicate:
 
     @classmethod
     def predicate_before_relative_time(cls, seconds: int) -> "ClaimPredicate":
-        """Returns a `before_relative_time` claim predicate.
+        """Returns a **before_relative_time** claim predicate.
 
         This predicate will be fulfilled if the closing time of the ledger that
         includes the :class:`CreateClaimableBalance` operation plus this relative time delta (in seconds)
         is less than the current time.
 
         :param seconds: seconds since closeTime of the ledger in which the ClaimableBalanceEntry was created.
-        :return: a `before_relative_time` claim predicate.
+        :return: a **before_relative_time** claim predicate.
         """
         return cls(
             claim_predicate_type=ClaimPredicateType.CLAIM_PREDICATE_BEFORE_RELATIVE_TIME,
@@ -169,9 +172,9 @@ class ClaimPredicate:
 
     @classmethod
     def predicate_unconditional(cls) -> "ClaimPredicate":
-        """Returns an unconditional claim predicate.
+        """Returns an **unconditional** claim predicate.
 
-        :return: an unconditional claim predicate.
+        :return: an **unconditional** claim predicate.
         """
         return cls(
             claim_predicate_type=ClaimPredicateType.CLAIM_PREDICATE_UNCONDITIONAL,
@@ -285,7 +288,7 @@ class ClaimPredicate:
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return (
             self.claim_predicate_type == other.claim_predicate_type
             and self.and_predicates == other.and_predicates
@@ -306,6 +309,7 @@ class ClaimPredicate:
         )
 
 
+@type_checked
 class Claimant:
     """The :class:`Claimant` object represents a claimable balance claimant.
 
@@ -318,6 +322,7 @@ class Claimant:
         if predicate is None:
             predicate = ClaimPredicate.predicate_unconditional()
         self.predicate: ClaimPredicate = predicate
+        raise_if_not_valid_ed25519_public_key(self.destination, "destination")
 
     def to_xdr_object(self) -> stellar_xdr.Claimant:
         claimant_v0 = stellar_xdr.ClaimantV0(
@@ -342,7 +347,7 @@ class Claimant:
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return (
             self.destination == other.destination and self.predicate == other.predicate
         )
@@ -353,22 +358,23 @@ class Claimant:
         )
 
 
+@type_checked
 class CreateClaimableBalance(Operation):
     """The :class:`CreateClaimableBalance` object, which represents a CreateClaimableBalance
     operation on Stellar's network.
 
-    Creates a ClaimableBalanceEntry. See `Claimable Balance
-    <https://developers.stellar.org/docs/glossary/claimable-balance/>_` for more information on parameters and usage.
-
-    See `Create Claimable Balance
-    <https://developers.stellar.org/docs/start/list-of-operations/#create-claimable-balance>_`.
+    Creates a ClaimableBalanceEntry.
+    See `Claimable Balance <https://developers.stellar.org/docs/glossary/claimable-balance/>`_
+    for more information on parameters and usage.
 
     Threshold: Medium
 
+    See `Create Claimable Balance <https://developers.stellar.org/docs/start/list-of-operations/#create-claimable-balance>`_ for more information.
+
     :param asset: The asset for the claimable balance.
     :param amount: the amount of the asset.
     :param claimants: A list of Claimants.
-    :param source: The source account (defaults to transaction source).
+    :param source: The source account for the operation. Defaults to the transaction's source account.
     """
 
     _XDR_OPERATION_TYPE: stellar_xdr.OperationType = (
@@ -383,10 +389,10 @@ class CreateClaimableBalance(Operation):
         source: Optional[Union[MuxedAccount, str]] = None,
     ) -> None:
         super().__init__(source)
-        check_amount(amount)
-        self.asset = asset
-        self.amount = amount
-        self.claimants = claimants
+        self.asset: Asset = asset
+        self.amount: str = str(amount)
+        self.claimants: List[Claimant] = claimants
+        raise_if_not_valid_amount(self.amount, "amount")
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
         asset = self.asset.to_xdr_object()
