@@ -5,12 +5,14 @@ from .. import xdr as stellar_xdr
 from ..asset import Asset
 from ..muxed_account import MuxedAccount
 from ..price import Price
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_amount
 from .operation import Operation
-from .utils import check_amount, check_price
 
 __all__ = ["CreatePassiveSellOffer"]
 
 
+@type_checked
 class CreatePassiveSellOffer(Operation):
     """The :class:`CreatePassiveSellOffer` object, which represents a
     CreatePassiveSellOffer operation on Stellar's network.
@@ -30,16 +32,18 @@ class CreatePassiveSellOffer(Operation):
     two passive sell offers so the two offers don't immediately act on each other.
 
     Once the passive sell offer is created, you can manage it like any other offer
-    using the manage offer operation - see :class:`ManageOffer` for more
+    using the manage offer operation - see :class:`ManageBuyOffer` for more
     details.
 
+    Threshold: Medium
+
+    See `Create Passive Sell Offer <https://developers.stellar.org/docs/start/list-of-operations/#create-passive-sell-offer>`_ for more information.
+
     :param selling: What you're selling.
     :param buying: What you're buying.
-    :param amount: The total amount you're selling. If 0,
-        deletes the offer.
-    :param price: Price of 1 unit of `selling` in
-        terms of `buying`.
-    :param source: The source account (defaults to transaction source).
+    :param amount: The total amount you're selling. If 0, deletes the offer.
+    :param price: Price of 1 unit of `selling` in terms of `buying`.
+    :param source: The source account for the operation. Defaults to the transaction's source account.
 
     """
 
@@ -56,23 +60,19 @@ class CreatePassiveSellOffer(Operation):
         source: Optional[Union[MuxedAccount, str]] = None,
     ) -> None:
         super().__init__(source)
-        check_amount(amount)
-        check_price(price)
+        if not isinstance(price, Price):
+            price = Price.from_raw_price(price)
+
         self.selling: Asset = selling
         self.buying: Asset = buying
-        self.amount: Union[str, Decimal] = amount
-        self.price: Union[Price, str, Decimal] = price
+        self.amount: str = str(amount)
+        self.price: Price = price
+        raise_if_not_valid_amount(self.amount, "amount")
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
         selling = self.selling.to_xdr_object()
         buying = self.buying.to_xdr_object()
-
-        if isinstance(self.price, Price):
-            price_fraction = self.price
-        else:
-            price_fraction = Price.from_raw_price(self.price)
-
-        price = price_fraction.to_xdr_object()
+        price = self.price.to_xdr_object()
         amount = stellar_xdr.Int64(Operation.to_xdr_amount(self.amount))
         create_passive_sell_offer_op = stellar_xdr.CreatePassiveSellOfferOp(
             selling, buying, amount, price
