@@ -2,11 +2,13 @@ from typing import Optional, Union
 
 from .. import xdr as stellar_xdr
 from ..muxed_account import MuxedAccount
+from ..type_checked import type_checked
 from .operation import Operation
 
 __all__ = ["Inflation"]
 
 
+@type_checked
 class Inflation(Operation):
     """The :class:`Inflation` object, which represents a
     Inflation operation on Stellar's network.
@@ -15,8 +17,7 @@ class Inflation(Operation):
 
     Threshold: Low
 
-    :param str source: The source account (defaults to transaction source).
-
+    :param source: The source account for the operation. Defaults to the transaction's source account.
     """
 
     _XDR_OPERATION_TYPE: stellar_xdr.OperationType = stellar_xdr.OperationType.INFLATION
