@@ -3,11 +3,13 @@ from typing import Optional, Union
 from .. import xdr as stellar_xdr
 from ..exceptions import ValueError
 from ..muxed_account import MuxedAccount
+from ..type_checked import type_checked
 from .operation import Operation
 
 __all__ = ["ManageData"]
 
 
+@type_checked
 class ManageData(Operation):
     """The :class:`ManageData` object, which represents a
     ManageData operation on Stellar's network.
@@ -22,8 +24,13 @@ class ManageData(Operation):
 
     Threshold: Medium
 
-    :param data_name: The name of the data entry.
-    :param data_value: The value of the data entry.
+    See `Manage Data <https://developers.stellar.org/docs/start/list-of-operations/#manage-data>`_ for more information.
+
+    :param data_name: If this is a new Name
+        it will add the given name/value pair to the account. If this Name
+        is already present then the associated value will be modified. Up to 64 bytes long.
+    :param data_value: If not present then the existing `data_name` will be deleted.
+        If present then this value will be set in the DataEntry. Up to 64 bytes long.
     :param source: The optional source account.
 
     """
@@ -37,12 +44,12 @@ class ManageData(Operation):
         data_name: str,
         data_value: Union[str, bytes, None],
         source: Optional[Union[MuxedAccount, str]] = None,
-    ) -> None:  # TODO: bytes only?
+    ) -> None:
         super().__init__(source)
         self.data_name: str = data_name
         if isinstance(data_value, str):
             data_value = data_value.encode()
-        self.data_value: Union[bytes, None] = data_value
+        self.data_value: Optional[bytes] = data_value
 
         valid_data_name_len = len(self.data_name) <= 64
         valid_data_val_len = self.data_value is None or len(self.data_value) <= 64
@@ -72,7 +79,6 @@ class ManageData(Operation):
         """
         source = Operation.get_source_from_xdr_obj(xdr_object)
         assert xdr_object.body.manage_data_op is not None
-        # TODO: should we decode it?
         data_name = xdr_object.body.manage_data_op.data_name.string64.decode()
         data_value_xdr = xdr_object.body.manage_data_op.data_value
         data_value = None if data_value_xdr is None else data_value_xdr.data_value
