@@ -4,11 +4,13 @@ from typing import Optional, Union
 
 from .. import xdr as stellar_xdr
 from ..muxed_account import MuxedAccount
+from ..type_checked import type_checked
 from ..xdr import utils as xdr_utils
 
 __all__ = ["Operation"]
 
 
+@type_checked
 class Operation(metaclass=ABCMeta):
     """The :class:`Operation` object, which represents an operation on
     Stellar's network.
@@ -21,9 +23,9 @@ class Operation(metaclass=ABCMeta):
     transaction, unless there is an override defined for the operation.
 
     For more on operations, see `Stellar's documentation on operations
-    <https://www.stellar.org/developers/guides/concepts/operations.html>`_ as
+    <https://developers.stellar.org/docs/glossary/operations/>`_ as
     well as `Stellar's List of Operations
-    <https://www.stellar.org/developers/guides/concepts/list-of-operations.html>`_,
+    <https://developers.stellar.org/docs/start/list-of-operations/>`_,
     which includes information such as the security necessary for a given
     operation, as well as information about when validity checks occur on the
     network.
@@ -31,7 +33,7 @@ class Operation(metaclass=ABCMeta):
     The :class:`Operation` class is typically not used, but rather one of its
     subclasses is typically included in transactions.
 
-    :param source: The source account for the payment. Defaults to the
+    :param source: The source account for the operation. Defaults to the
         transaction's source account.
 
     """
@@ -63,7 +65,7 @@ class Operation(metaclass=ABCMeta):
         in order to come to the integer value used in XDR structures.
 
         See `Stellar's documentation on Asset Precision
-        <https://www.stellar.org/developers/guides/concepts/assets.html#amount-precision-and-representation>`_
+        <https://developers.stellar.org/docs/issuing-assets/anatomy-of-an-asset/#amount-precision>`_
         for more information.
 
         :param value: The amount to convert to an integer for XDR
@@ -126,5 +128,5 @@ class Operation(metaclass=ABCMeta):
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return self.to_xdr_object() == other.to_xdr_object()
