@@ -4,12 +4,14 @@ from typing import List, Optional, Union
 from .. import xdr as stellar_xdr
 from ..asset import Asset
 from ..muxed_account import MuxedAccount
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_amount
 from .operation import Operation
-from .utils import check_amount
 
 __all__ = ["PathPaymentStrictReceive"]
 
 
+@type_checked
 class PathPaymentStrictReceive(Operation):
     """The :class:`PathPaymentStrictReceive` object, which represents a PathPaymentStrictReceive
     operation on Stellar's network.
@@ -20,13 +22,15 @@ class PathPaymentStrictReceive(Operation):
 
     Threshold: Medium
 
+    See `Path Payment Strict Receive <https://developers.stellar.org/docs/start/list-of-operations/#path-payment-strict-receive>`_ for more information.
+
     :param destination: The destination account to send to.
-    :param send_asset: The asset to pay with.
-    :param send_max: The maximum amount of send_asset to send.
-    :param dest_asset: The asset the destination will receive.
-    :param dest_amount: The amount the destination receives.
+    :param send_asset: The `asset` to pay with.
+    :param send_max: The maximum amount of `send_asset` to send.
+    :param dest_asset: The asset the `destination` will receive.
+    :param dest_amount: The amount the `destination` receives.
     :param path: A list of Asset objects to use as the path.
-    :param source: The source account for the payment. Defaults to the
+    :param source: The source account for the operation. Defaults to the
         transaction's source account.
     """
 
@@ -45,16 +49,16 @@ class PathPaymentStrictReceive(Operation):
         source: Optional[Union[MuxedAccount, str]] = None,
     ) -> None:
         super().__init__(source)
-        check_amount(send_max)
-        check_amount(dest_amount)
         if isinstance(destination, str):
             destination = MuxedAccount.from_account(destination)
         self.destination: MuxedAccount = destination
         self.send_asset: Asset = send_asset
-        self.send_max: Union[str, Decimal] = send_max
+        self.send_max: str = str(send_max)
         self.dest_asset: Asset = dest_asset
-        self.dest_amount: Union[str, Decimal] = dest_amount
+        self.dest_amount: str = str(dest_amount)
         self.path: List[Asset] = path  # a list of paths/assets
+        raise_if_not_valid_amount(self.send_max, "send_max")
+        raise_if_not_valid_amount(self.dest_amount, "dest_amount")
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
         destination = self.destination.to_xdr_object()
