@@ -11,8 +11,13 @@ from ..liquidity_pool_id import LiquidityPoolId
 from ..muxed_account import MuxedAccount
 from ..signer_key import SignerKey
 from ..strkey import StrKey
+from ..type_checked import type_checked
+from ..utils import (
+    raise_if_not_valid_balance_id,
+    raise_if_not_valid_ed25519_public_key,
+    raise_if_not_valid_hash,
+)
 from .operation import Operation
-from .utils import check_ed25519_public_key
 
 __all__ = ["RevokeSponsorship"]
 
@@ -29,60 +34,64 @@ class RevokeSponsorshipType(IntEnum):
     LIQUIDITY_POOL = 6
 
 
+@type_checked
 class TrustLine:
     def __init__(self, account_id: str, asset: Union[Asset, LiquidityPoolId]) -> None:
-        check_ed25519_public_key(account_id)
         self.account_id = account_id
         self.asset = asset
+        raise_if_not_valid_ed25519_public_key(self.account_id, "account_id")
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return self.account_id == other.account_id and self.asset == other.asset
 
     def __str__(self):
         return f"<TrustLine [account_id={self.account_id}, asset={self.asset}]>"
 
 
+@type_checked
 class Offer:
     def __init__(self, seller_id: str, offer_id: int) -> None:
-        check_ed25519_public_key(seller_id)
         self.seller_id = seller_id
         self.offer_id = offer_id
+        raise_if_not_valid_ed25519_public_key(self.seller_id, "seller_id")
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return self.seller_id == other.seller_id and self.offer_id == other.offer_id
 
     def __str__(self):
         return f"<Offer [seller_id={self.seller_id}, offer_id={self.offer_id}]>"
 
 
+@type_checked
 class Data:
     def __init__(self, account_id: str, data_name: str) -> None:
-        check_ed25519_public_key(account_id)
         self.account_id = account_id
         self.data_name = data_name
+        raise_if_not_valid_ed25519_public_key(self.account_id, "account_id")
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return self.account_id == other.account_id and self.data_name == other.data_name
 
     def __str__(self):
         return f"<Data [account_id={self.account_id}, data_name={self.data_name}]>"
 
 
+@type_checked
 class Signer:
     def __init__(self, account_id: str, signer_key: SignerKey) -> None:
-        check_ed25519_public_key(account_id)
         self.account_id = account_id
         self.signer_key = signer_key
+        raise_if_not_valid_ed25519_public_key(self.account_id, "account_id")
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return (
             self.account_id == other.account_id and self.signer_key == other.signer_key
         )
@@ -91,6 +100,7 @@ class Signer:
         return f"<Signer [account_id={self.account_id}, signer_key={self.signer_key}]>"
 
 
+@type_checked
 class RevokeSponsorship(Operation):
     """The :class:`RevokeSponsorship` object, which represents a RevokeSponsorship
     operation on Stellar's network.
@@ -101,13 +111,12 @@ class RevokeSponsorship(Operation):
     then attempt to revoke the sponsorship. If the source account is sponsored, the next step depends on whether the
     entry is sponsored or not. If it is sponsored, attempt to transfer the sponsorship to the sponsor
     of the source account. If the entry is not sponsored, then establish the sponsorship.
-    See `Sponsored Reserves <https://developers.stellar.org/docs/glossary/sponsored-reserves/>_` for more information.
-
-    See `Revoke Sponsorship
-    <https://developers.stellar.org/docs/start/list-of-operations/#revoke-sponsorship>_`.
+    See `Sponsored Reserves <https://developers.stellar.org/docs/glossary/sponsored-reserves/>`_ for more information.
 
     Threshold: Medium
 
+    See `Revoke Sponsorship <https://developers.stellar.org/docs/start/list-of-operations/#revoke-sponsorship>`_ for more information.
+
     :param revoke_sponsorship_type: The sponsored account id.
     :param account_id: The sponsored account ID.
     :param trustline: The sponsored trustline.
@@ -115,7 +124,7 @@ class RevokeSponsorship(Operation):
     :param data: The sponsored data.
     :param claimable_balance_id: The sponsored claimable balance.
     :param signer: The sponsored signer.
-    :param source: The source account (defaults to transaction source).
+    :param source: The source account for the operation. Defaults to the transaction's source account.
     """
 
     _XDR_OPERATION_TYPE: stellar_xdr.OperationType = (
@@ -135,23 +144,32 @@ class RevokeSponsorship(Operation):
         source: Optional[Union[MuxedAccount, str]] = None,
     ) -> None:
         super().__init__(source)
-        self.revoke_sponsorship_type = revoke_sponsorship_type
-        self.account_id = account_id
-        self.trustline = trustline
-        self.offer = offer
-        self.data = data
-        self.claimable_balance_id = claimable_balance_id
-        self.signer = signer
-        self.liquidity_pool_id = liquidity_pool_id
+        self.revoke_sponsorship_type: RevokeSponsorshipType = revoke_sponsorship_type
+        self.account_id: Optional[str] = account_id
+        self.trustline: Optional[TrustLine] = trustline
+        self.offer: Optional[Offer] = offer
+        self.data: Optional[Data] = data
+        self.claimable_balance_id: Optional[str] = claimable_balance_id
+        self.signer: Optional[Signer] = signer
+        self.liquidity_pool_id: Optional[str] = liquidity_pool_id
+
+        if self.account_id is not None:
+            raise_if_not_valid_ed25519_public_key(self.account_id, "account_id")
+        if self.claimable_balance_id is not None:
+            raise_if_not_valid_balance_id(
+                self.claimable_balance_id, "claimable_balance_id"
+            )
+        if self.liquidity_pool_id is not None:
+            raise_if_not_valid_hash(self.liquidity_pool_id, "liquidity_pool_id")
 
     @classmethod
     def revoke_account_sponsorship(
         cls, account_id: str, source: Optional[Union[MuxedAccount, str]] = None
     ):
-        """Create a "revoke sponsorship" operation for an account.
+        """Create a **revoke sponsorship** operation for an account.
 
         :param account_id: The sponsored account ID.
-        :param source: The source account (defaults to transaction source).
+        :param source: The source account for the operation. Defaults to the transaction's source account.
         :return: A "revoke sponsorship" operation for an account.
         """
         return cls(
@@ -173,11 +191,11 @@ class RevokeSponsorship(Operation):
         asset: Union[Asset, LiquidityPoolId],
         source: Optional[Union[MuxedAccount, str]] = None,
     ):
-        """Create a "revoke sponsorship" operation for a trustline.
+        """Create a **revoke sponsorship** operation for a trustline.
 
         :param account_id: The account ID which owns the trustline.
         :param asset: The asset in the trustline.
-        :param source: The source account (defaults to transaction source).
+        :param source: The source account for the operation. Defaults to the transaction's source account.
         :return: A "revoke sponsorship" operation for a trustline.
         """
         trustline = TrustLine(account_id=account_id, asset=asset)
@@ -200,11 +218,11 @@ class RevokeSponsorship(Operation):
         offer_id: int,
         source: Optional[Union[MuxedAccount, str]] = None,
     ):
-        """Create a "revoke sponsorship" operation for an offer.
+        """Create a **revoke sponsorship** operation for an offer.
 
         :param seller_id: The account ID which created the offer.
         :param offer_id: The offer ID.
-        :param source: The source account (defaults to transaction source).
+        :param source: The source account for the operation. Defaults to the transaction's source account.
         :return: A "revoke sponsorship" operation for an offer.
         """
         offer = Offer(seller_id=seller_id, offer_id=offer_id)
@@ -227,11 +245,11 @@ class RevokeSponsorship(Operation):
         data_name: str,
         source: Optional[Union[MuxedAccount, str]] = None,
     ):
-        """Create a "revoke sponsorship" operation for a data entry.
+        """Create a **revoke sponsorship** operation for a data entry.
 
         :param account_id: The account ID which owns the data entry.
         :param data_name: The name of the data entry
-        :param source: The source account (defaults to transaction source).
+        :param source: The source account for the operation. Defaults to the transaction's source account.
         :return: A "revoke sponsorship" operation for a data entry.
         """
         data = Data(account_id=account_id, data_name=data_name)
@@ -253,10 +271,10 @@ class RevokeSponsorship(Operation):
         claimable_balance_id: str,
         source: Optional[Union[MuxedAccount, str]] = None,
     ):
-        """Create a "revoke sponsorship" operation for a claimable balance.
+        """Create a **revoke sponsorship** operation for a claimable balance.
 
         :param claimable_balance_id: The sponsored claimable balance ID.
-        :param source: The source account (defaults to transaction source).
+        :param source: The source account for the operation. Defaults to the transaction's source account.
         :return: A "revoke sponsorship" operation for a claimable balance.
         """
         return cls(
@@ -278,11 +296,11 @@ class RevokeSponsorship(Operation):
         signer_key: SignerKey,
         source: Optional[Union[MuxedAccount, str]] = None,
     ):
-        """Create a "revoke sponsorship" operation for a signer.
+        """Create a **revoke sponsorship** operation for a signer.
 
         :param account_id: The account ID where the signer sponsorship is being removed from.
         :param signer_key: The signer whose sponsorship is being removed.
-        :param source: The source account (defaults to transaction source).
+        :param source: The source account for the operation. Defaults to the transaction's source account.
         :return: A "revoke sponsorship" operation for a signer.
         """
         signer = Signer(account_id=account_id, signer_key=signer_key)
@@ -302,10 +320,10 @@ class RevokeSponsorship(Operation):
     def revoke_liquidity_pool_sponsorship(
         cls, liquidity_pool_id: str, source: Optional[Union[MuxedAccount, str]] = None
     ):
-        """Create a "revoke sponsorship" operation for a liquidity pool.
+        """Create a **revoke sponsorship** operation for a liquidity pool.
 
         :param liquidity_pool_id: The sponsored liquidity pool ID in hex string.
-        :param source: The source account (defaults to transaction source).
+        :param source: The source account for the operation. Defaults to the transaction's source account.
         :return: A "revoke sponsorship" operation for a liquidity pool.
         """
         return cls(
@@ -513,7 +531,7 @@ class RevokeSponsorship(Operation):
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return (
             self.revoke_sponsorship_type == other.revoke_sponsorship_type
             and self.account_id == other.account_id
