@@ -14,6 +14,7 @@ from mnemonic import Mnemonic
 from mnemonic.mnemonic import PBKDF2_ROUNDS
 
 from ..exceptions import ValueError
+from ..type_checked import type_checked
 
 
 @unique
@@ -30,8 +31,11 @@ class Language(Enum):
     CHINESE_TRADITIONAL = "chinese_traditional"
 
 
+@type_checked
 class StellarMnemonic(Mnemonic):
-    """Please use :meth:`Keypair.generate_mnemonic_phrase` and :meth:`Keypair.from_mnemonic_phrase`"""
+    """Please use :func:`stellar_sdk.keypair.Keypair.generate_mnemonic_phrase`
+    and :func:`stellar_sdk.keypair.Keypair.from_mnemonic_phrase`
+    """
 
     STELLAR_ACCOUNT_PATH_FORMAT = "m/44'/148'/%d'"
     FIRST_HARDENED_INDEX = 0x80000000
