@@ -13,17 +13,17 @@ import time
 from typing import Iterable, List, Optional, Union
 
 from .. import xdr as stellar_xdr
-from ..memo import IdMemo, NoneMemo
 from ..account import Account
-from ..muxed_account import MuxedAccount
-from ..exceptions import BadSignatureError, ValueError
+from ..exceptions import BadSignatureError, FeatureNotEnabledError, ValueError
 from ..keypair import Keypair
+from ..memo import IdMemo, NoneMemo
+from ..muxed_account import MuxedAccount
 from ..operation.manage_data import ManageData
 from ..transaction_builder import TransactionBuilder
 from ..transaction_envelope import TransactionEnvelope
+from ..type_checked import type_checked
 from .ed25519_public_key_signer import Ed25519PublicKeySigner
 from .exceptions import InvalidSep10ChallengeError
-from ..exceptions import FeatureNotEnabledError
 
 __all__ = [
     "build_challenge_transaction",
@@ -34,9 +34,11 @@ __all__ = [
     "verify_challenge_transaction",
 ]
 
+
 MUXED_ACCOUNT_STARTING_LETTER: str = "M"
 
 
+@type_checked
 class ChallengeTransaction:
     """Used to store the results produced
     by :func:`stellar_sdk.sep.stellar_web_authentication.read_challenge_transaction`.
@@ -61,7 +63,7 @@ class ChallengeTransaction:
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return (
             self.transaction == other.transaction
             and self.client_account_id == other.client_account_id
@@ -73,6 +75,7 @@ class ChallengeTransaction:
         return f"<ChallengeTransaction [transaction={self.transaction}, client_account_id={self.client_account_id}, memo={self.memo}, matched_home_domain={self.matched_home_domain}]>"
 
 
+@type_checked
 def build_challenge_transaction(
     server_secret: str,
     client_account_id: str,
@@ -88,12 +91,13 @@ def build_challenge_transaction(
     challenge transaction which you can use for Stellar Web Authentication.
 
     :param server_secret: secret key for server's stellar.toml `SIGNING_KEY`.
-    :param client_account_id: The stellar account (`G...`) or muxed account (`M...`) that the wallet wishes to authenticate with the server.
+    :param client_account_id: The stellar account (``G...``) or
+        muxed account (``M...``) that the wallet wishes to authenticate with the server.
     :param home_domain: The `fully qualified domain name <https://en.wikipedia.org/wiki/Fully_qualified_home_domain>`_
-        of the service requiring authentication, for example: `example.com`.
+        of the service requiring authentication (ex. ``"example.com"``).
     :param web_auth_domain: The fully qualified domain name of the service issuing the challenge.
     :param network_passphrase: The network to connect to for verifying and retrieving
-        additional attributes from. (ex. 'Public Global Stellar Network ; September 2015')
+        additional attributes from. (ex. ``"Public Global Stellar Network ; September 2015"``)
     :param timeout: Challenge duration in seconds (default to 15 minutes).
     :param client_domain: The domain of the client application requesting authentication
     :param client_signing_key: The stellar account listed as the SIGNING_KEY on the client domain's TOML file
@@ -104,12 +108,10 @@ def build_challenge_transaction(
         raise ValueError(
             "memos are not valid for challenge transactions with a muxed client account"
         )
-    if memo and not isinstance(memo, int):
-        raise ValueError("memo must be an integer")
 
     now = int(time.time())
     server_keypair = Keypair.from_secret(server_secret)
-    server_account = Account(account_id=server_keypair.public_key, sequence=-1)
+    server_account = Account(account=server_keypair.public_key, sequence=-1)
     transaction_builder = TransactionBuilder(server_account, network_passphrase, 100)
     transaction_builder.add_time_bounds(min_time=now, max_time=now + timeout)
     nonce = os.urandom(48)
@@ -140,6 +142,7 @@ def build_challenge_transaction(
     return transaction.to_xdr()
 
 
+@type_checked
 def read_challenge_transaction(
     challenge_transaction: str,
     server_account_id: str,
@@ -154,8 +157,9 @@ def read_challenge_transaction(
     It does not verify that the transaction has been signed by the client or
     that any signatures other than the servers on the transaction are valid. Use
     one of the following functions to completely verify the transaction:
-        - :func:`stellar_sdk.sep.stellar_web_authentication.verify_challenge_transaction_threshold`
-        - :func:`stellar_sdk.sep.stellar_web_authentication.verify_challenge_transaction_signers`
+
+    * :func:`stellar_sdk.sep.stellar_web_authentication.verify_challenge_transaction_threshold`
+    * :func:`stellar_sdk.sep.stellar_web_authentication.verify_challenge_transaction_signers`
 
     :param challenge_transaction: SEP0010 transaction challenge transaction in base64.
     :param server_account_id: public key for server's account.
@@ -164,7 +168,7 @@ def read_challenge_transaction(
     :param web_auth_domain: The home domain that is expected to be included as the value of the Manage Data operation with
         the 'web_auth_domain' key. If no such operation is included, this parameter is not used.
     :param network_passphrase: The network to connect to for verifying and retrieving
-        additional attributes from. (ex. 'Public Global Stellar Network ; September 2015')
+        additional attributes from. (ex. ``"Public Global Stellar Network ; September 2015"``)
     :raises: :exc:`InvalidSep10ChallengeError <stellar_sdk.sep.exceptions.InvalidSep10ChallengeError>` - if the
         validation fails, the exception will be thrown.
     """
@@ -241,7 +245,9 @@ def read_challenge_transaction(
         raise InvalidSep10ChallengeError("Operation should have a source account.")
 
     try:
-        client_account_address = client_account.account_muxed or client_account.account_id
+        client_account_address = (
+            client_account.account_muxed or client_account.account_id
+        )
     except FeatureNotEnabledError:
         if client_account.account_muxed_id:
             raise InvalidSep10ChallengeError("Muxed accounts are not supported")
@@ -326,6 +332,7 @@ def read_challenge_transaction(
     )
 
 
+@type_checked
 def verify_challenge_transaction_signers(
     challenge_transaction: str,
     server_account_id: str,
@@ -349,7 +356,7 @@ def verify_challenge_transaction_signers(
     :param web_auth_domain: The home domain that is expected to be included as the value of the Manage Data
         operation with the 'web_auth_domain' key, if present.
     :param network_passphrase: The network to connect to for verifying and retrieving
-        additional attributes from. (ex. 'Public Global Stellar Network ; September 2015')
+        additional attributes from. (ex. ``"Public Global Stellar Network ; September 2015"``)
     :param signers: The signers of client account.
 
     :raises: :exc:`InvalidSep10ChallengeError <stellar_sdk.sep.exceptions.InvalidSep10ChallengeError>`:
@@ -423,7 +430,7 @@ def verify_challenge_transaction_signers(
 
     if client_signing_key and not client_signing_key_found:
         raise InvalidSep10ChallengeError(
-            f"Transaction not signed by the source account of the 'client_domain' "
+            "Transaction not signed by the source account of the 'client_domain' "
             "ManageData operation"
         )
 
@@ -438,6 +445,7 @@ def verify_challenge_transaction_signers(
     return signers_found
 
 
+@type_checked
 def verify_challenge_transaction_signed_by_client_master_key(
     challenge_transaction: str,
     server_account_id: str,
@@ -454,7 +462,7 @@ def verify_challenge_transaction_signed_by_client_master_key(
     :param web_auth_domain: The home domain that is expected to be included as the value of the Manage Data operation with
         the 'web_auth_domain' key. If no such operation is included, this parameter is not used.
     :param network_passphrase: The network to connect to for verifying and retrieving
-        additional attributes from. (ex. 'Public Global Stellar Network ; September 2015')
+        additional attributes from. (ex. ``"Public Global Stellar Network ; September 2015"``)
 
     :raises: :exc:`InvalidSep10ChallengeError <stellar_sdk.sep.exceptions.InvalidSep10ChallengeError>` - if the
         validation fails, the exception will be thrown.
@@ -469,6 +477,7 @@ def verify_challenge_transaction_signed_by_client_master_key(
     )
 
 
+@type_checked
 def verify_challenge_transaction_threshold(
     challenge_transaction: str,
     server_account_id: str,
@@ -492,7 +501,7 @@ def verify_challenge_transaction_threshold(
     :param web_auth_domain: The home domain that is expected to be included as the value of the Manage Data operation with
         the 'web_auth_domain' key. If no such operation is included, this parameter is not used.
     :param network_passphrase: The network to connect to for verifying and retrieving
-        additional attributes from. (ex. 'Public Global Stellar Network ; September 2015')
+        additional attributes from. (ex. ``"Public Global Stellar Network ; September 2015"``)
     :param threshold: The medThreshold on the client account.
     :param signers: The signers of client account.
 
@@ -519,6 +528,7 @@ def verify_challenge_transaction_threshold(
     return signers_found
 
 
+@type_checked
 def verify_challenge_transaction(
     challenge_transaction: str,
     server_account_id: str,
@@ -544,9 +554,9 @@ def verify_challenge_transaction(
     :param home_domains: The home domain that is expected to be included in the first Manage Data operation's string
         key. If a list is provided, one of the domain names in the array must match.
     :param web_auth_domain: The home domain that is expected to be included as the value of the Manage Data
-        operation with the 'web_auth_domain' key, if present.
+        operation with the `web_auth_domain` key, if present.
     :param network_passphrase: The network to connect to for verifying and retrieving
-        additional attributes from. (ex. 'Public Global Stellar Network ; September 2015')
+        additional attributes from. (ex. ``"Public Global Stellar Network ; September 2015"``)
     :raises: :exc:`InvalidSep10ChallengeError <stellar_sdk.sep.exceptions.InvalidSep10ChallengeError>` - if the
         validation fails, the exception will be thrown.
     """
@@ -597,10 +607,10 @@ def _verify_transaction_signatures(
             # See https://github.com/StellarCN/py-stellar-base/issues/252#issuecomment-580882560
             if index in signature_used:
                 continue
-            if decorated_signature.hint.signature_hint != kp.signature_hint():
+            if decorated_signature.signature_hint != kp.signature_hint():
                 continue
             try:
-                kp.verify(tx_hash, decorated_signature.signature.signature)
+                kp.verify(tx_hash, decorated_signature.signature)
                 signature_used.add(index)
                 signers_found.append(signer)
                 break
