@@ -14,6 +14,7 @@ from typing import Dict, List, Optional, Union
 
 from .. import xdr as stellar_xdr
 from ..asset import Asset
+from ..decorated_signature import DecoratedSignature
 from ..exceptions import ValueError as SdkValueError
 from ..fee_bump_transaction import FeeBumpTransaction
 from ..fee_bump_transaction_envelope import FeeBumpTransactionEnvelope
@@ -31,6 +32,7 @@ from ..strkey import StrKey
 from ..time_bounds import TimeBounds
 from ..transaction import Transaction
 from ..transaction_envelope import TransactionEnvelope
+from ..type_checked import type_checked
 
 __all__ = ["to_txrep", "from_txrep"]
 
@@ -44,6 +46,7 @@ class _EnvelopeType(Enum):
     ENVELOPE_TYPE_TX_FEE_BUMP = "ENVELOPE_TYPE_TX_FEE_BUMP"
 
 
+@type_checked
 def to_txrep(
     transaction_envelope: Union[TransactionEnvelope, FeeBumpTransactionEnvelope],
 ) -> str:
@@ -55,7 +58,6 @@ def to_txrep(
 
     See `SEP-0011 <https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0011.md>`_
 
-
     :param transaction_envelope: Transaction envelope object.
     :return: A human-readable format for Stellar transactions.
     """
@@ -124,6 +126,7 @@ def to_txrep(
 
 
 # Setting to ignore pass in .coveragerc will cause this function to not be counted by pytest.
+@type_checked
 def from_txrep(
     txrep: str, network_passphrase: str
 ) -> Union[TransactionEnvelope, FeeBumpTransactionEnvelope]:
@@ -293,18 +296,16 @@ def _remove_string_value_comment(value: str) -> str:
 
 def _get_signature(
     index: int, raw_data_map: Dict[str, str], prefix: str
-) -> stellar_xdr.DecoratedSignature:
+) -> DecoratedSignature:
     hint = _get_bytes_value(raw_data_map, f"{prefix}signatures[{index}].hint")
     signature = _get_bytes_value(raw_data_map, f"{prefix}signatures[{index}].signature")
-    return stellar_xdr.DecoratedSignature(
-        stellar_xdr.SignatureHint(hint), stellar_xdr.Signature(signature)
-    )
+    return DecoratedSignature(hint, signature)
 
 
 def _get_signatures(
     raw_data_map: Dict[str, str], prefix: str
-) -> List[stellar_xdr.DecoratedSignature]:
-    signatures: List[stellar_xdr.DecoratedSignature] = []
+) -> List[DecoratedSignature]:
+    signatures: List[DecoratedSignature] = []
     signature_length = _get_int_value(raw_data_map, f"{prefix}signatures.len")
     for i in range(signature_length):
         signature = _get_signature(i, raw_data_map, prefix)
@@ -637,7 +638,9 @@ def _get_change_trust_op(
         fee = _get_int_value(
             raw_data_map, f"{operation_prefix}line.liquidityPool.constantProduct.fee"
         )
-        line: Union[Asset, LiquidityPoolAsset] = LiquidityPoolAsset(asset_a, asset_b, fee)
+        line: Union[Asset, LiquidityPoolAsset] = LiquidityPoolAsset(
+            asset_a, asset_b, fee
+        )
     else:
         line = _get_asset(raw_data_map, f"{operation_prefix}line")
     limit = _get_amount_value(raw_data_map, f"{operation_prefix}limit")
@@ -1086,37 +1089,7 @@ def _add_operation(
         add_body_line("signer._present", _false if signer is None else _true)
         if signer is None:
             return
-        if (
-            signer.signer_key.signer_key.type
-            == stellar_xdr.SignerKeyType.SIGNER_KEY_TYPE_ED25519
-        ):
-            assert signer.signer_key.signer_key.ed25519 is not None
-            add_body_line(
-                "signer.key",
-                StrKey.encode_ed25519_public_key(
-                    signer.signer_key.signer_key.ed25519.uint256
-                ),
-            )
-        if (
-            signer.signer_key.signer_key.type
-            == stellar_xdr.SignerKeyType.SIGNER_KEY_TYPE_PRE_AUTH_TX
-        ):
-            assert signer.signer_key.signer_key.pre_auth_tx is not None
-            add_body_line(
-                "signer.key",
-                StrKey.encode_pre_auth_tx(
-                    signer.signer_key.signer_key.pre_auth_tx.uint256
-                ),
-            )
-        if (
-            signer.signer_key.signer_key.type
-            == stellar_xdr.SignerKeyType.SIGNER_KEY_TYPE_HASH_X
-        ):
-            assert signer.signer_key.signer_key.hash_x is not None
-            add_body_line(
-                "signer.key",
-                StrKey.encode_sha256_hash(signer.signer_key.signer_key.hash_x.uint256),
-            )
+        add_body_line("signer.key", signer.signer_key.encoded_signer_key)
         add_body_line("signer.weight", signer.weight)
 
     def add_price(price: Union[Price, str, Decimal]) -> None:
@@ -1242,8 +1215,18 @@ def _add_operation(
         add_price(operation.price)
     elif isinstance(operation, SetOptions):
         add_body_line("inflationDest", operation.inflation_dest, True)
-        add_body_line("clearFlags", operation.clear_flags, True)
-        add_body_line("setFlags", operation.set_flags, True)
+        add_body_line(
+            "clearFlags",
+            operation.clear_flags.value if operation.clear_flags else None,
+            True,
+            comment=operation.clear_flags,
+        )
+        add_body_line(
+            "setFlags",
+            operation.set_flags.value if operation.set_flags else None,
+            True,
+            comment=operation.set_flags,
+        )
         add_body_line("masterWeight", operation.master_weight, True)
         add_body_line("lowThreshold", operation.low_threshold, True)
         add_body_line("medThreshold", operation.med_threshold, True)
@@ -1408,41 +1391,27 @@ def _add_operation(
                 stellar_xdr.revoke_sponsorship_type.RevokeSponsorshipType.REVOKE_SPONSORSHIP_SIGNER.name,
             )
             add_body_line("signer.accountID", operation.signer.account_id)
+            signer_key_xdr = operation.signer.signer_key.to_xdr_object()
             add_body_line(
                 "signer.signerKey.type",
-                operation.signer.signer_key.signer_key.type.name,
+                signer_key_xdr.type.name,
             )
-            if (
-                operation.signer.signer_key.signer_key.type
-                == stellar_xdr.SignerKeyType.SIGNER_KEY_TYPE_HASH_X
-            ):
-                assert operation.signer.signer_key.signer_key.hash_x is not None
-                key = StrKey.encode_sha256_hash(
-                    operation.signer.signer_key.signer_key.hash_x.uint256
-                )
+            key = operation.signer.signer_key.encoded_signer_key
+            if signer_key_xdr.type == stellar_xdr.SignerKeyType.SIGNER_KEY_TYPE_HASH_X:
                 add_body_line("signer.signerKey.hashX", key)
             elif (
-                operation.signer.signer_key.signer_key.type
-                == stellar_xdr.SignerKeyType.SIGNER_KEY_TYPE_ED25519
+                signer_key_xdr.type == stellar_xdr.SignerKeyType.SIGNER_KEY_TYPE_ED25519
             ):
-                assert operation.signer.signer_key.signer_key.ed25519 is not None
-                key = StrKey.encode_ed25519_public_key(
-                    operation.signer.signer_key.signer_key.ed25519.uint256
-                )
                 add_body_line("signer.signerKey.ed25519", key)
             elif (
-                operation.signer.signer_key.signer_key.type
+                signer_key_xdr.type
                 == stellar_xdr.SignerKeyType.SIGNER_KEY_TYPE_PRE_AUTH_TX
             ):
-                assert operation.signer.signer_key.signer_key.pre_auth_tx is not None
-                key = StrKey.encode_pre_auth_tx(
-                    operation.signer.signer_key.signer_key.pre_auth_tx.uint256
-                )
                 add_body_line("signer.signerKey.preAuthTx", key)
             else:
                 raise SdkValueError(
                     f"This signer key type has not been implemented yet, "
-                    f"signer key type: {operation.signer.signer_key.signer_key.type}."
+                    f"signer key type: {signer_key_xdr.type}."
                 )
         else:
             raise SdkValueError(
@@ -1507,7 +1476,7 @@ def _add_operation(
 
 
 def _add_signatures(
-    signatures: List[stellar_xdr.DecoratedSignature], prefix: str, lines: List[str]
+    signatures: List[DecoratedSignature], prefix: str, lines: List[str]
 ) -> None:
     _add_line(f"{prefix}signatures.len", len(signatures), lines)
     for index, signature in enumerate(signatures):
@@ -1515,11 +1484,11 @@ def _add_signatures(
 
 
 def _add_signature(
-    index: int, signature: stellar_xdr.DecoratedSignature, prefix: str, lines: List[str]
+    index: int, signature: DecoratedSignature, prefix: str, lines: List[str]
 ) -> None:
     prefix = f"{prefix}signatures[{index}]."
-    _add_line(f"{prefix}hint", _to_opaque(signature.hint.signature_hint), lines)
-    _add_line(f"{prefix}signature", _to_opaque(signature.signature.signature), lines)
+    _add_line(f"{prefix}hint", _to_opaque(signature.signature_hint), lines)
+    _add_line(f"{prefix}signature", _to_opaque(signature.signature), lines)
 
 
 def _to_asset(asset: Union[Asset, LiquidityPoolAsset, LiquidityPoolId]) -> str:
