@@ -1,4 +1,4 @@
-from typing import List, Union
+from typing import List, Optional, Union
 
 from . import xdr as stellar_xdr
 from .keypair import Keypair
@@ -7,10 +7,12 @@ from .muxed_account import MuxedAccount
 from .operation.operation import Operation
 from .strkey import StrKey
 from .time_bounds import TimeBounds
+from .type_checked import type_checked
 
 __all__ = ["Transaction"]
 
 
+@type_checked
 class Transaction:
     """The :class:`Transaction` object, which represents a transaction(Transaction or TransactionV0)
     on Stellar's network.
@@ -27,15 +29,15 @@ class Transaction:
     on transactions`_.
 
     .. _Stellar's guide on transactions:
-        https://www.stellar.org/developers/guides/concepts/transactions.html
+        https://developers.stellar.org/docs/glossary/transactions/
 
     :param source: the source account for the transaction.
     :param sequence: The sequence number for the transaction.
-    :param fee: The fee amount for the transaction, which should equal
-          FEE (currently 100 stroops) multiplied by the number of
+    :param fee: The max fee amount for the transaction, which should equal
+          FEE (currently least 100 stroops) multiplied by the number of
           operations in the transaction. See `Stellar's latest documentation
           on fees
-          <https://www.stellar.org/developers/guides/concepts/fees.html#transaction-fee>`_
+          <https://developers.stellar.org/docs/glossary/fees/#transaction-fee>`__
           for more information.
     :param operations: A list of operations objects (typically its
           subclasses as defined in :mod:`stellar_sdk.operation.Operation`.
@@ -43,9 +45,9 @@ class Transaction:
     :param memo: The memo being sent with the transaction, being
           represented as one of the subclasses of the
           :class:`Memo <stellar_sdk.memo.Memo>` object.
-    :param v1: When this value is set to True, V1 transactions will be generated,
+    :param v1: When this value is set to ``True``, V1 transactions will be generated,
         otherwise V0 transactions will be generated.
-        See `CAP-0015 <https://github.com/stellar/stellar-protocol/blob/master/core/cap-0015.md>`_ for more information.
+        See `CAP-0015 <https://github.com/stellar/stellar-protocol/blob/master/core/cap-0015.md>`__ for more information.
     """
 
     def __init__(
@@ -70,12 +72,12 @@ class Transaction:
             source = MuxedAccount.from_account(source.public_key)
 
         self.source: MuxedAccount = source
-        self.sequence = sequence
-        self.operations = operations
-        self.memo = memo
-        self.fee = fee
-        self.time_bounds = time_bounds
-        self.v1 = v1
+        self.sequence: int = sequence
+        self.operations: List[Operation] = operations
+        self.memo: Memo = memo
+        self.fee: int = fee
+        self.time_bounds: Optional[TimeBounds] = time_bounds
+        self.v1: bool = v1
 
     def to_xdr_object(
         self,
@@ -188,7 +190,7 @@ class Transaction:
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return self.to_xdr_object() == other.to_xdr_object()
 
     def __str__(self):
