@@ -2,23 +2,28 @@ import hashlib
 import os
 import re
 from decimal import ROUND_FLOOR, Decimal
-from typing import List
+from typing import Dict, List, Optional, Union
 from urllib.parse import urlsplit, urlunsplit
 
-from . import xdr as stellar_xdr
 from .asset import Asset
-from .exceptions import NoApproximationError, TypeError
+from .exceptions import Ed25519PublicKeyInvalidError, NoApproximationError, ValueError
 from .strkey import StrKey
+from .type_checked import type_checked
 
 MUXED_ACCOUNT_STARTING_LETTER: str = "M"
 ED25519_PUBLIC_KEY_STARTING_LETTER: str = "G"
+_LOWER_LIMIT = "0"
+_UPPER_LIMIT = "922337203685.4775807"
+_EXPONENT = 7
 
 
+@type_checked
 def sha256(data: bytes) -> bytes:
     return hashlib.sha256(data).digest()
 
 
-def best_rational_approximation(x):
+@type_checked
+def best_rational_approximation(x) -> Dict[str, int]:
     x = Decimal(x)
     int32_max = Decimal(2147483647)
     fractions = [[Decimal(0), Decimal(1)], [Decimal(1), Decimal(0)]]
@@ -44,14 +49,14 @@ def best_rational_approximation(x):
     return {"n": int(n), "d": int(d)}
 
 
-def hex_to_bytes(hex_string):
-    if isinstance(hex_string, bytes):
-        return hex_string
+@type_checked
+def hex_to_bytes(hex_string: Union[str, bytes]) -> bytes:
     if isinstance(hex_string, str):
         return bytes.fromhex(hex_string)
-    raise TypeError("`hex_string` should be a 32 byte hash or hex encoded string.")
+    return hex_string
 
 
+@type_checked
 def convert_assets_to_horizon_param(assets: List[Asset]) -> str:
     assets_string = []
     for asset in assets:
@@ -62,7 +67,8 @@ def convert_assets_to_horizon_param(assets: List[Asset]) -> str:
     return ",".join(assets_string)
 
 
-def urljoin_with_query(base: str, path: str) -> str:
+@type_checked
+def urljoin_with_query(base: str, path: Optional[str]) -> str:
     split_url = urlsplit(base)
     query = split_url.query
     real_path = split_url.path
@@ -74,33 +80,49 @@ def urljoin_with_query(base: str, path: str) -> str:
     return url
 
 
-def parse_ed25519_account_id_from_muxed_account_xdr_object(
-    data: stellar_xdr.MuxedAccount,
-) -> str:
-    if data.ed25519 is not None:
-        return StrKey.encode_ed25519_public_key(data.ed25519.uint256)
-    assert data.med25519 is not None
-    return StrKey.encode_ed25519_public_key(data.med25519.ed25519.uint256)
-
-
-def is_fee_bump_transaction(xdr: str) -> bool:
-    xdr_object = stellar_xdr.TransactionEnvelope.from_xdr(xdr)
-    te_type = xdr_object.type
-    if te_type == stellar_xdr.EnvelopeType.ENVELOPE_TYPE_TX_FEE_BUMP:
-        return True
-    elif (
-        te_type == stellar_xdr.EnvelopeType.ENVELOPE_TYPE_TX
-        or te_type == stellar_xdr.EnvelopeType.ENVELOPE_TYPE_TX_V0
-    ):
-        return False
-    else:
-        raise ValueError(
-            f"This transaction envelope type is not supported, type = {te_type}."
-        )
-
-
+@type_checked
 def is_valid_hash(data: str) -> bool:
     if not data:
         return False
     asset_code_re = re.compile(r"^[a-zA-Z0-9]{64}$")
     return bool(asset_code_re.match(data))
+
+
+@type_checked
+def raise_if_not_valid_ed25519_public_key(value: str, argument_name: str) -> None:
+    try:
+        StrKey.decode_ed25519_public_key(value)
+    except Exception as e:
+        raise Ed25519PublicKeyInvalidError(
+            f'Value of argument "{argument_name}" is not a valid ed25519 public key: {value}'
+        ) from e
+
+
+@type_checked
+def raise_if_not_valid_amount(value: str, argument_name: str) -> None:
+    amount = Decimal(value)
+    if abs(amount.as_tuple().exponent) > _EXPONENT:
+        raise ValueError(
+            f'Value of argument "{argument_name}" must have at most 7 digits after the decimal: {amount}'
+        )
+    if amount < Decimal(_LOWER_LIMIT) or amount > Decimal(_UPPER_LIMIT):
+        raise ValueError(
+            f'Value of argument "{argument_name}" must represent a positive number '
+            f"and the max valid value is {_UPPER_LIMIT}: {amount}"
+        )
+
+
+@type_checked
+def raise_if_not_valid_hash(value: str, argument_name: str) -> None:
+    if not is_valid_hash(value):
+        raise ValueError(
+            f'Value of argument "{argument_name}" is not a valid hash: {value}'
+        )
+
+
+@type_checked
+def raise_if_not_valid_balance_id(value: str, argument_name: str) -> None:
+    if len(value) != 72 or value[:8] != "00000000" or not is_valid_hash(value[8:]):
+        raise ValueError(
+            f'Value of argument "{argument_name}" is not a valid balance id: {value}'
+        )
